==> digikam-3.3.0-beta1.tar.bz2: digikam-3.3.0-beta1/extra/kipi-plugins/photivointegration/kipiplugin_photivointegration.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=Photivo Integration
Name=Photivo Integration
Name[ca]=Integració de Photivo
Name[ca@valencia]=Integració de Photivo
Name[cs]=Integrace Photivo
Name[da]=Photivo-integration
Name[de]=Photivo-Einbindung
Name[el]=Ενσωμάτωση Photivo
Name[es]=Integración con Photivo
Name[et]=Photivo lõimimine
Name[fr]=Intégration Photivo
Name[gl]=Integración con Photivo
Name[hu]=Photivo integráció
Name[is]=Innbygging Photivo
Name[it]=Integrazione di Photivo
Name[nb]=Photivo-integrasjon
Name[nl]=Photivo-integratie
Name[pl]=Integracja Photivo
Name[pt]=Integração com o Photivo
Name[pt_BR]=Integração com o Photivo
Name[sl]=Podpora za Photivo
Name[sv]=Integrering av Photivo
Name[uk]=Інтеграція Photivo
Name[x-test]=xxPhotivo Integrationxx
Name[zh_TW]=Photivo 整合
Comment=Integration of the Photivo RAW-Processor
Comment[ca]=Integració del processador RAW Photivo
Comment[ca@valencia]=Integració del processador RAW Photivo
Comment[da]=Integration af RAW-behandleren Photivo
Comment[el]=Ενσωμάτωση του RAW-επεξεργαστή Photivo
Comment[es]=Integración con el procesador RAW de Photivo
Comment[et]=Lõimimine Photivo toorpiltide töötlejaga
Comment[fr]=Intégration du processus Photivo RAW
Comment[gl]=Integración co procesador en cru Photivo.
Comment[hu]=A Photivo RAW feldolgozó integrációja
Comment[is]=Innbygging Photivo RAW-meðhöndlunar í kerfið
Comment[it]=Integrazione dell'elaboratore RAW Photivo
Comment[nb]=Integrasjon av Photivo RAW-behandler
Comment[nl]=Integratie van de Photivo RAW-processor
Comment[pl]=Integracja programu przetwarzającego RAW Photivo
Comment[pt]=Integração com o Processador RAW Photivo
Comment[pt_BR]=Integração com o Processador RAW Photivo
Comment[sl]=Podpora za obdelovalnik RAW Photivo
Comment[sv]=Integrering av Photivo bearbetning av obehandlade bilder
Comment[uk]=Інтеграція програми для обробки цифрових негативів Photivo
Comment[x-test]=xxIntegration of the Photivo RAW-Processorxx
Comment[zh_TW]=與 Photivo RAW-Processor 整合
Type=Service
Icon=photivo
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_photivointegration
author=Dominic Lyons, domlyons at googlemail dot com
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=

==> digikam-4.0.0-beta1.tar.bz2: digikam-4.0.0-beta1/extra/kipi-plugins/photivointegration/kipiplugin_photivointegration.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=Photivo Integration
Name=Photivo Integration
Name[ca]=Integració de Photivo
Name[ca@valencia]=Integració de Photivo
Name[cs]=Integrace Photivo
Name[da]=Photivo-integration
Name[de]=Photivo-Einbindung
Name[el]=Ενσωμάτωση Photivo
Name[es]=Integración con Photivo
Name[et]=Photivo lõimimine
Name[fr]=Intégration « Photivo »
Name[gl]=Integración con Photivo
Name[hu]=Photivo integráció
Name[is]=Innbygging Photivo
Name[it]=Integrazione di Photivo
Name[nb]=Photivo-integrasjon
Name[nl]=Photivo-integratie
Name[pl]=Integracja Photivo
Name[pt]=Integração com o Photivo
Name[pt_BR]=Integração com o Photivo
Name[sk]=Integrácia Photivo
Name[sl]=Podpora za Photivo
Name[sv]=Integrering av Photivo
Name[tr]=Photivo Bütünleştirmesi
Name[uk]=Інтеграція Photivo
Name[x-test]=xxPhotivo Integrationxx
Name[zh_TW]=Photivo 整合
Comment=Integration of the Photivo RAW-Processor
Comment[ca]=Integració del processador RAW Photivo
Comment[ca@valencia]=Integració del processador RAW Photivo
Comment[cs]=Integrace nástroje pro zpracování RAW Photivo
Comment[da]=Integration af RAW-behandleren Photivo
Comment[el]=Ενσωμάτωση του RAW-επεξεργαστή Photivo
Comment[es]=Integración con el procesador RAW de Photivo
Comment[et]=Lõimimine Photivo toorpiltide töötlejaga
Comment[fr]=Intégration du processus « Photivo RAW »
Comment[gl]=Integración co procesador en cru Photivo.
Comment[hu]=A Photivo RAW feldolgozó integrációja
Comment[is]=Innbygging Photivo RAW-meðhöndlunar í kerfið
Comment[it]=Integrazione dell'elaboratore RAW Photivo
Comment[nb]=Integrasjon av Photivo RAW-behandler
Comment[nl]=Integratie van de Photivo RAW-processor
Comment[pl]=Integracja programu przetwarzającego RAW Photivo
Comment[pt]=Integração com o Processador RAW Photivo
Comment[pt_BR]=Integração com o Processador RAW Photivo
Comment[sl]=Podpora za obdelovalnik RAW Photivo
Comment[sv]=Integrering av Photivo bearbetning av obehandlade bilder
Comment[tr]=Photivo HAM-İşleyici bütünleştirmesi
Comment[uk]=Інтеграція програми для обробки цифрових негативів Photivo
Comment[x-test]=xxIntegration of the Photivo RAW-Processorxx
Comment[zh_TW]=與 Photivo RAW-Processor 整合
Type=Service
Icon=kipi-photivo
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_photivointegration
author=Dominic Lyons, domlyons at googlemail dot com
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=
